@@ -13,12 +13,13 @@
 #include "settings.h"
 
 #include <QVarLengthArray>
+#include <KLocalizedString>
 
-KBlocksScene::KBlocksScene(GameLogicInterface * p, int capacity)
+KBlocksScene::KBlocksScene(GameLogicInterface *p, int capacity)
 {
     mpGameLogic = p;
     mGameStarted = false;
-    
+
     mSnapshotMode = false;
     mTopGameLevel = 0;
     mGroupCount = 0;
@@ -26,25 +27,25 @@ KBlocksScene::KBlocksScene(GameLogicInterface * p, int capacity)
     mSceneGamesPerLine = 4;
     mGameAnimEnabled = true;
     mWaitForAllUpdate = false;
-    
+
     maGroupList = new KBlocksItemGroup*[capacity]();
     maGameScoreList = new KBlocksScore*[capacity]();
     maGameReadySignal = new bool[capacity]();
-    
+
     QString themeFile(Settings::theme());
     mpGrafx = new KBlocksGraphics(themeFile);
     mpSnd = new KBlocksSound(themeFile);
-    
+
     int width = (capacity >= mSceneGamesPerLine) ? mSceneGamesPerLine : (capacity % mSceneGamesPerLine);
     int height = (int)(capacity / (mSceneGamesPerLine + 1)) + 1;
     setSceneRect(0, 0, mpGrafx->m_View_Size_Width * width,
-                       mpGrafx->m_View_Size_Height * height);
-    
+                 mpGrafx->m_View_Size_Height * height);
+
     setItemIndexMethod(NoIndex);
-    
+
     mUpdateInterval = 50;
     mUpdateTimer.setInterval(mUpdateInterval);
-    connect(&mUpdateTimer, SIGNAL(timeout()), SLOT(updateGame()));
+    connect(&mUpdateTimer, &QTimer::timeout, this, &KBlocksScene::updateGame);
     mUpdateTimer.stop();
 }
 
@@ -53,49 +54,47 @@ KBlocksScene::~KBlocksScene()
     delete [] maGameReadySignal;
     delete [] maGameScoreList;
     delete [] maGroupList;
-    
+
     delete mpGrafx;
     delete mpSnd;
 }
 
-KBlocksItemGroup* KBlocksScene::getItemGroup(int index)
+KBlocksItemGroup *KBlocksScene::getItemGroup(int index)
 {
     return maGroupList[index];
 }
 
-KBlocksScore* KBlocksScene::getScoreHandler(int index)
+KBlocksScore *KBlocksScene::getScoreHandler(int index)
 {
     return maGameScoreList[index];
 }
 
 void KBlocksScene::createGameItemGroups(int groupCount, bool snapshotMode)
 {
-    if (groupCount > mMaxCapacity)
-    {
+    if (groupCount > mMaxCapacity) {
         mGroupCount = mMaxCapacity;
     }
     mGroupCount = groupCount;
     mSnapshotMode = snapshotMode;
     mTopGameLevel = 0;
-    
-    for(int i = 0; i < mGroupCount; i++)
-    {
+
+    for (int i = 0; i < mGroupCount; i++) {
         maGroupList[i] = new KBlocksItemGroup(i, mpGameLogic->getSingleGame(i), mpGrafx, mpSnd, snapshotMode);
         maGroupList[i]->setUpdateInterval(mUpdateInterval);
         maGroupList[i]->setGameAnimEnabled(mGameAnimEnabled);
         maGroupList[i]->setWaitForAllUpdate(mWaitForAllUpdate);
         addItem(maGroupList[i]);
-        
+
         maGameScoreList[i] = new KBlocksScore();
         maGameScoreList[i]->setLevelUpFactor(KBlocksScore_Level_x_Level_x_Factor, 1000);
         maGameScoreList[i]->setScoreUpFactor(10);
-        
+
         maGameReadySignal[i] = false;
         connect(maGroupList[i], SIGNAL(readyForAction(int)), this, SLOT(readyForAction(int)));
     }
-    
+
     updateDimensions();
-	
+
     //Our Message Item, hidden by default
     mMessageBox = new KGamePopupItem();
     mMessageBox->setMessageOpacity(0.9);
@@ -107,13 +106,12 @@ void KBlocksScene::deleteGameItemGroups()
     removeItem(mMessageBox);
     delete mMessageBox;
 
-    for(int i = 0; i < mGroupCount; i++)
-    {
+    for (int i = 0; i < mGroupCount; i++) {
         disconnect(maGroupList[i], SIGNAL(readyForAction(int)), this, SLOT(readyForAction(int)));
-        
+
         delete maGameScoreList[i];
         maGameScoreList[i] = 0;
-        
+
         removeItem(maGroupList[i]);
         delete maGroupList[i];
         maGroupList[i] = 0;
@@ -129,8 +127,7 @@ void KBlocksScene::setGamesPerLine(int count)
 void KBlocksScene::setGameAnimEnabled(bool flag)
 {
     mGameAnimEnabled = flag;
-    for(int i = 0; i < mGroupCount; i++)
-    {
+    for (int i = 0; i < mGroupCount; i++) {
         maGroupList[i]->setGameAnimEnabled(flag);
     }
 }
@@ -138,8 +135,7 @@ void KBlocksScene::setGameAnimEnabled(bool flag)
 void KBlocksScene::setWaitForAllUpdate(bool flag)
 {
     mWaitForAllUpdate = flag;
-    for(int i = 0; i < mGroupCount; i++)
-    {
+    for (int i = 0; i < mGroupCount; i++) {
         maGroupList[i]->setWaitForAllUpdate(flag);
     }
 }
@@ -148,8 +144,7 @@ void KBlocksScene::setUpdateInterval(int interval)
 {
     mUpdateInterval = interval;
     mUpdateTimer.setInterval(mUpdateInterval);
-    for(int i = 0; i < mGroupCount; i++)
-    {
+    for (int i = 0; i < mGroupCount; i++) {
         maGroupList[i]->setUpdateInterval(mUpdateInterval);
     }
 }
@@ -159,10 +154,9 @@ void KBlocksScene::setSoundsEnabled(bool enabled)
     mpSnd->setSoundsEnabled(enabled);
 }
 
-void KBlocksScene::readSettings(const QSize & viewSize)
+void KBlocksScene::readSettings(const QSize &viewSize)
 {
-    if (mpGrafx->theme()->fileName()!=Settings::theme())
-    {
+    if (mpGrafx->theme()->fileName() != Settings::theme()) {
         mpGrafx->loadTheme(Settings::theme());
         mpSnd->loadTheme(Settings::theme());
         mpGrafx->adjustForSize(viewSize);
@@ -170,7 +164,7 @@ void KBlocksScene::readSettings(const QSize & viewSize)
     }
 }
 
-void KBlocksScene::viewScaled(const QSize& /*newsize*/)
+void KBlocksScene::viewScaled(const QSize & /*newsize*/)
 {
     /*
     //Temporarily halt game timer while resizing elements
@@ -184,20 +178,17 @@ void KBlocksScene::viewScaled(const QSize& /*newsize*/)
 
 void KBlocksScene::startGame()
 {
-    if (mGameStarted)
-    {
+    if (mGameStarted) {
         return;
     }
     mGameStarted = true;
-    
+
     mTopGameLevel = 0;
-    for(int i = 0; i < mGroupCount; i++)
-    {
+    for (int i = 0; i < mGroupCount; i++) {
         maGroupList[i]->startGame();
     }
-    
-    if (!mSnapshotMode)
-    {
+
+    if (!mSnapshotMode) {
         mUpdateTimer.start();
         QTimer::singleShot(500, this, SLOT(greetPlayer()));
     }
@@ -205,50 +196,40 @@ void KBlocksScene::startGame()
 
 void KBlocksScene::stopGame()
 {
-    if (!mGameStarted)
-    {
+    if (!mGameStarted) {
         return;
     }
     mGameStarted = false;
-    
-    for(int i = 0; i < mGroupCount; i++)
-    {
+
+    for (int i = 0; i < mGroupCount; i++) {
         maGroupList[i]->stopGame();
     }
-    
+
     mUpdateTimer.stop();
 }
 
 void KBlocksScene::pauseGame(bool flag, bool fromUI)
 {
-    if (!mGameStarted)
-    {
+    if (!mGameStarted) {
         return;
     }
-    
+
     QString resuming(i18n("Game Resumed!"));
     QString pausing(i18n("Game Paused!"));
-    
-    for(int i = 0; i < mGroupCount; i++)
-    {
+
+    for (int i = 0; i < mGroupCount; i++) {
         maGroupList[i]->pauseGame(flag);
     }
-    
-    if (!mSnapshotMode)
-    {
-        if (flag)
-        {
+
+    if (!mSnapshotMode) {
+        if (flag) {
             mUpdateTimer.stop();
-            if (!fromUI)
-            {
+            if (!fromUI) {
                 showMessage(pausing, 2000);
             }
-        }
-        else
-        {
+        } else {
             mUpdateTimer.start();
-            if (!fromUI)
-            {
+            if (!fromUI) {
                 showMessage(resuming, 2000);
             }
         }
@@ -257,14 +238,13 @@ void KBlocksScene::pauseGame(bool flag, bool fromUI)
 
 void KBlocksScene::addScore(int gameIndex, int lineCount)
 {
-    if (!mSnapshotMode)
-    {
+    if (!mSnapshotMode) {
         return;
     }
     maGameScoreList[gameIndex]->addScore(lineCount);
     emit scoreChanged(gameIndex, maGameScoreList[gameIndex]->getScorePoint(),
-                                 maGameScoreList[gameIndex]->getLineCount(), 
-                                 maGameScoreList[gameIndex]->getGameLevel());
+                      maGameScoreList[gameIndex]->getLineCount(),
+                      maGameScoreList[gameIndex]->getGameLevel());
 }
 
 void KBlocksScene::updateDimensions()
@@ -272,15 +252,14 @@ void KBlocksScene::updateDimensions()
     // TODO : Reset item position and scale
     int width = (mGroupCount >= mSceneGamesPerLine) ? mSceneGamesPerLine : (mGroupCount % mSceneGamesPerLine);
     int height = (int)(mGroupCount / (mSceneGamesPerLine + 1)) + 1;
-    
+
     setSceneRect(0, 0, mpGrafx->m_View_Size_Width * width,
-                       mpGrafx->m_View_Size_Height * height);
-    
-    for(int i = 0; i < mGroupCount; i++)
-    {
+                 mpGrafx->m_View_Size_Height * height);
+
+    for (int i = 0; i < mGroupCount; i++) {
         int left = mpGrafx->m_View_Size_Width * (i % mSceneGamesPerLine);
         int top = mpGrafx->m_View_Size_Height * ((int)(i / mSceneGamesPerLine));
-        
+
         maGroupList[i]->setPos(left, top);
         maGroupList[i]->refreshPosition();
     }
@@ -288,88 +267,74 @@ void KBlocksScene::updateDimensions()
 
 void KBlocksScene::greetPlayer()
 {
-    QString greets(i18n("Game Start!")); 
-    showMessage( greets, 2000 );
+    QString greets(i18n("Game Start!"));
+    showMessage(greets, 2000);
 }
 
 void KBlocksScene::gameOverPlayer()
 {
-    QString greets(i18n("Game Over!")); 
-    showMessage( greets, 2000 );
+    QString greets(i18n("Game Over!"));
+    showMessage(greets, 2000);
 }
 
 void KBlocksScene::gameOverMultiWin()
 {
-    QString gameOver(i18n("You Win!")); 
-    showMessage( gameOver, 2000 );
+    QString gameOver(i18n("You Win!"));
+    showMessage(gameOver, 2000);
 }
 
 void KBlocksScene::gameOverMultiLose()
 {
-    QString gameOver(i18n("You Lose!")); 
-    showMessage( gameOver, 2000 );
+    QString gameOver(i18n("You Lose!"));
+    showMessage(gameOver, 2000);
 }
 
-void KBlocksScene::showMessage(const QString& message, int ms)
+void KBlocksScene::showMessage(const QString &message, int ms)
 {
-    mMessageBox->setMessageTimeout( ms );
-    mMessageBox->showMessage( message, KGamePopupItem::TopLeft );
+    mMessageBox->setMessageTimeout(ms);
+    mMessageBox->showMessage(message, KGamePopupItem::TopLeft);
 }
 
 void KBlocksScene::updateGame()
 {
-    if (mSnapshotMode)
-    {
+    if (mSnapshotMode) {
         return;
     }
-    
+
     QVarLengthArray<int, 16> removedLines(mGroupCount);
     int gameCount = mpGameLogic->updateGame(removedLines.data());
-    
-    for(int i = 0; i < mGroupCount; i++)
-    {
-        if (removedLines[i] > 0)
-        {
-            if (maGameScoreList[i]->addScore(removedLines[i]))
-            {
+
+    for (int i = 0; i < mGroupCount; i++) {
+        if (removedLines[i] > 0) {
+            if (maGameScoreList[i]->addScore(removedLines[i])) {
                 int tmpLevel = maGameScoreList[i]->getGameLevel();
-                if (mTopGameLevel < tmpLevel)
-                {
+                if (mTopGameLevel < tmpLevel) {
                     mpGameLogic->levelUpGame(tmpLevel - mTopGameLevel);
                     mTopGameLevel = tmpLevel;
                 }
             }
             emit scoreChanged(i, maGameScoreList[i]->getScorePoint(),
-                                 maGameScoreList[i]->getLineCount(), 
-                                 maGameScoreList[i]->getGameLevel());
-        }
-        else if (removedLines[i] == -1)
-        {
+                              maGameScoreList[i]->getLineCount(),
+                              maGameScoreList[i]->getGameLevel());
+        } else if (removedLines[i] == -1) {
             maGroupList[i]->stopGame();
-            if (mGroupCount == 1)
-            {
+            if (mGroupCount == 1) {
                 QTimer::singleShot(500, this, SLOT(gameOverPlayer()));
                 emit isHighscore(0, maGameScoreList[0]->getScorePoint(),
-                                    maGameScoreList[0]->getGameLevel());
-            }
-            else
-            {
-                if (i == 0)
-                {
-                    for (int j = 0; j < mGroupCount; j++)
-                    {
+                                 maGameScoreList[0]->getGameLevel());
+            } else {
+                if (i == 0) {
+                    for (int j = 0; j < mGroupCount; j++) {
                         maGroupList[j]->stopGame();
                     }
                     QTimer::singleShot(500, this, SLOT(gameOverMultiLose()));
                     emit isHighscore(0, maGameScoreList[0]->getScorePoint(),
-                                        maGameScoreList[0]->getGameLevel());
-                }
-                else if (gameCount <= 1)
-                {
+                                     maGameScoreList[0]->getGameLevel());
+                } else if (gameCount <= 1) {
                     maGroupList[0]->stopGame();
                     QTimer::singleShot(500, this, SLOT(gameOverMultiWin()));
                     emit isHighscore(0, maGameScoreList[0]->getScorePoint(),
-                                        maGameScoreList[0]->getGameLevel());
+                                     maGameScoreList[0]->getGameLevel());
                 }
             }
         }
@@ -380,19 +345,14 @@ void KBlocksScene::readyForAction(int groupID)
 {
     maGameReadySignal[groupID] = true;
     bool allReady = true;
-    for(int i = 0; i < mGroupCount; i++)
-    {
-        if (!maGameReadySignal[i])
-        {
+    for (int i = 0; i < mGroupCount; i++) {
+        if (!maGameReadySignal[i]) {
             allReady = false;
         }
     }
-    if (allReady)
-    {
-        for(int i = 0; i < mGroupCount; i++)
-        {
-            if (mpGameLogic->getSingleGame(i)->isGameRunning())
-            {
+    if (allReady) {
+        for (int i = 0; i < mGroupCount; i++) {
+            if (mpGameLogic->getSingleGame(i)->isGameRunning()) {
                 maGameReadySignal[i] = false;
             }
         }
@@ -400,12 +360,10 @@ void KBlocksScene::readyForAction(int groupID)
     }
 }
 
-void KBlocksScene::drawBackground( QPainter * painter, const QRectF & rect )
+void KBlocksScene::drawBackground(QPainter *painter, const QRectF &rect)
 {
-    if (mpGrafx->renderer()->isValid())
-    {
+    if (mpGrafx->renderer()->isValid()) {
         mpGrafx->renderer()->render(painter, QString("BACKGROUND"), rect);
     }
 }
 
-
